@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <mailtransportakonadi_export.h>
+#include "mailtransportakonadi_export.h"
 
 #include <MailTransportAkonadi/DispatchModeAttribute>
 #include <MailTransportAkonadi/SentActionAttribute>
@@ -18,8 +18,8 @@
 
 #include <KCompositeJob>
 
+#include <Akonadi/AddressAttribute>
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/AddressAttribute>
 
 #include <KMime/KMimeMessage>
 
@@ -150,4 +150,3 @@ private:
     std::unique_ptr<MessageQueueJobPrivate> const d;
 };
 } // namespace MailTransport
-
